@@ -278,31 +278,31 @@
  * If the "xadd" operation is available on this architecture,
  * ISC_PLATFORM_HAVEXADD will be defined.
  */
-#define ISC_PLATFORM_HAVEXADD 1
+#undef ISC_PLATFORM_HAVEXADD
 
 /*
  * If the "xaddq" operation (64bit xadd) is available on this architecture,
  * ISC_PLATFORM_HAVEXADDQ will be defined.
  */
-#define ISC_PLATFORM_HAVEXADDQ 1
+#undef ISC_PLATFORM_HAVEXADDQ
 
 /*
  * If the 32-bit "atomic swap" operation is available on this
  * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
-#define ISC_PLATFORM_HAVEATOMICSTORE 1
+#undef ISC_PLATFORM_HAVEATOMICSTORE
 
 /*
  * If the 64-bit "atomic swap" operation is available on this
  * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
-#define ISC_PLATFORM_HAVEATOMICSTOREQ 1
+#undef ISC_PLATFORM_HAVEATOMICSTOREQ
 
 /*
  * If the "compare-and-exchange" operation is available on this architecture,
  * ISC_PLATFORM_HAVECMPXCHG will be defined.
  */
-#define ISC_PLATFORM_HAVECMPXCHG 1
+#undef ISC_PLATFORM_HAVECMPXCHG
 
 /*
  * If <stdatomic.h> is available on this architecture,
@@ -313,7 +313,7 @@
 /*
  * Define if gcc ASM extension is available
  */
-#define ISC_PLATFORM_USEGCCASM 1
+#undef ISC_PLATFORM_USEGCCASM
 
 /*
  * Define if Tru64 style ASM syntax must be used.
@@ -328,7 +328,7 @@
 /*
  * Define with the busy wait nop asm or function call.
  */
-#define ISC_PLATFORM_BUSYWAITNOP asm("rep; nop")
+
 
 /*
  * Define if the platform has <strings.h>.
